@@ -223,6 +223,9 @@ pycurl_inet_ntop (int family, void *addr, char *string, size_t string_size);
 # elif defined(HAVE_CURL_SECTRANSP)
 #   define COMPILE_SSL_LIB "secure-transport"
 #   define COMPILE_SUPPORTED_SSL_BACKEND_FOUND 1
+# elif defined(HAVE_CURL_SCHANNEL)
+#   define COMPILE_SSL_LIB "schannel"
+#   define COMPILE_SUPPORTED_SSL_BACKEND_FOUND 1
 # else
 #  ifdef _MSC_VER
     /* sigh */
@@ -240,7 +243,7 @@ pycurl_inet_ntop (int family, void *addr, char *string, size_t string_size);
     * no reason to require users match those */
 #  define COMPILE_SSL_LIB "none/other"
 #  define COMPILE_SUPPORTED_SSL_BACKEND_FOUND 0
-# endif /* HAVE_CURL_OPENSSL || HAVE_CURL_WOLFSSL || HAVE_CURL_GNUTLS || HAVE_CURL_NSS || HAVE_CURL_MBEDTLS || HAVE_CURL_SECTRANSP */
+# endif /* HAVE_CURL_OPENSSL || HAVE_CURL_WOLFSSL || HAVE_CURL_GNUTLS || HAVE_CURL_NSS || HAVE_CURL_MBEDTLS || HAVE_CURL_SECTRANSP || HAVE_CURL_SCHANNEL */
 #else
 # define COMPILE_SSL_LIB "none/other"
 # define COMPILE_SUPPORTED_SSL_BACKEND_FOUND 0
@@ -462,6 +465,9 @@ typedef struct CurlObject {
     PyObject *seek_cb;
     PyObject *sockopt_cb;
     PyObject *ssh_key_cb;
+#if LIBCURL_VERSION_NUM >= MAKE_LIBCURL_VERSION(7, 80, 0)
+    PyObject *prereq_cb;
+#endif
     /* file objects */
     PyObject *readdata_fp;
     PyObject *writedata_fp;
@@ -555,7 +561,7 @@ assert_curl_state(const CurlObject *self);
 PYCURL_INTERNAL PyObject *
 do_global_init(PyObject *dummy, PyObject *args);
 PYCURL_INTERNAL PyObject *
-do_global_cleanup(PyObject *dummy);
+do_global_cleanup(PyObject *dummy, PyObject *Py_UNUSED(ignored));
 PYCURL_INTERNAL PyObject *
 do_version_info(PyObject *dummy, PyObject *args);
 
@@ -570,12 +576,12 @@ PYCURL_INTERNAL PyObject *
 do_curl_set_ca_certs(CurlObject *self, PyObject *args);
 #endif
 PYCURL_INTERNAL PyObject *
-do_curl_perform(CurlObject *self);
+do_curl_perform(CurlObject *self, PyObject *Py_UNUSED(ignored));
 PYCURL_INTERNAL PyObject *
-do_curl_perform_rb(CurlObject *self);
+do_curl_perform_rb(CurlObject *self, PyObject *Py_UNUSED(ignored));
 #if PY_MAJOR_VERSION >= 3
 PYCURL_INTERNAL PyObject *
-do_curl_perform_rs(CurlObject *self);
+do_curl_perform_rs(CurlObject *self, PyObject *Py_UNUSED(ignored));
 #else
 # define do_curl_perform_rs do_curl_perform_rb
 #endif
@@ -604,10 +610,10 @@ do_curl_getinfo(CurlObject *self, PyObject *args);
 # define do_curl_getinfo do_curl_getinfo_raw
 #endif
 PYCURL_INTERNAL PyObject *
-do_curl_errstr(CurlObject *self);
+do_curl_errstr(CurlObject *self, PyObject *Py_UNUSED(ignored));
 #if PY_MAJOR_VERSION >= 3
 PYCURL_INTERNAL PyObject *
-do_curl_errstr_raw(CurlObject *self);
+do_curl_errstr_raw(CurlObject *self, PyObject *Py_UNUSED(ignored));
 #else
 # define do_curl_errstr_raw do_curl_errstr
 #endif
@@ -652,6 +658,11 @@ ioctl_callback(CURL *curlobj, int cmd, void *stream);
 PYCURL_INTERNAL CURLcode
 ssl_ctx_callback(CURL *curl, void *ssl_ctx, void *ptr);
 #endif
+#if LIBCURL_VERSION_NUM >= MAKE_LIBCURL_VERSION(7, 80, 0)
+PYCURL_INTERNAL int
+prereq_callback(void *clientp, char *conn_primary_ip, char *conn_local_ip,
+                int conn_primary_port, int conn_local_port);
+#endif
 
 #if !defined(PYCURL_SINGLE_FILE)
 /* Type objects */
@@ -701,5 +712,10 @@ extern PyMethodDef curlmultiobject_methods[];
 # define CPy_TRASHCAN_END(op) Py_TRASHCAN_SAFE_END(op)
 #endif
 
+#ifdef PYCURL_AUTODETECT_CA
+extern char *g_pycurl_autodetected_cainfo;
+extern char *g_pycurl_autodetected_capath;
+#endif
+
 /* vi:ts=4:et:nowrap
  */
